/*
 * Copyright 1999 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

/*
 * Name:  dbtest.c
 *
 * This program tests a file of MX database records to verify that the
 * records are correctly formatted.
 */

#include <stdio.h>
#include <string.h>
#include <stdlib.h>

#include "motor.h"

FILE *output;
MX_RECORD *motor_record_list;

/* The following are just to satisfy some external references by routines
 * in "../motor/mshow.c" that are not used by this program.
 */

int motor_overwrite_flag = 0;
int motor_header_prompt_flag = 0;

int
cmd_show_history_buffer( void )
{
	return SUCCESS;
}

int
main( int argc, char *argv[] )
{
	MX_RECORD *current_record;
	MX_DRIVER *driver;
	long *num_record_fields;
	char buffer[100];
	char *token;
	int status;
	mx_status_type mx_status;

	if ( argc != 2 ) {
		fprintf( stderr, "Usage: dbtest 'database_filename'\n" );
		exit(1);
	}

	output = stdout;

	motor_record_list = mx_initialize_record_list();

	if ( motor_record_list == (MX_RECORD *) NULL ) {
		fprintf(stderr,"Attempt to initialize record list failed.\n");
		exit(1);
	}

	mx_status = mx_initialize_record_types();

	if ( mx_status.code != MXE_SUCCESS ) {
		fprintf(stderr,"Attempt to initialize record types failed.\n");
		exit(1);
	}

	mx_status = mx_read_database_file( motor_record_list, argv[1] );

	if ( mx_status.code != MXE_SUCCESS ) {
		fprintf(stderr,"Attempt to load database '%s' failed.\n",
				argv[1]);
		exit(1);
	}

	/* If we were setting up the database for real, we would next
	 * invoke the function mx_finish_database_initialization().
	 */

	fprintf(output,"\ndbtest:  '%s' is correctly formatted.\n\n", argv[1]);

	fprintf(output,"Type 'list' for a list of records, 'quit' to exit,\n");
	fprintf(output,"or the name of a record to display its contents.\n\n");

	while (1) {
		fprintf( output, "dbtest> " );
		fflush( output );

		fgets( buffer, sizeof buffer, stdin );

		token = strtok( buffer, " \t\n" );

		if ( token == NULL ) {
			continue;	/* Go back to the top of the loop. */
		}

		if ( strcmp( token, "list" ) == 0 ) {
			current_record = motor_record_list;

			do {
				fprintf( output, "%*s   ",
					-MXU_RECORD_NAME_LENGTH,
					current_record->name );

				driver = mx_get_driver_by_type(
						mx_type_list,
						current_record->type );

				if ( driver == NULL ) {
					fprintf(output,"(Unknown type %ld)\n",
						current_record->type );
				} else {
					fprintf(output, "%*s ",
						-MXU_DRIVER_NAME_LENGTH,
						driver->name );

					num_record_fields
					  = driver->num_record_fields;

					if ( num_record_fields == NULL ) {
						fprintf( output,
						  "(Old style record)\n" );
					} else {
						fprintf( output,
						  "%ld record fields\n",
						  *num_record_fields );
					}
				}
				current_record = current_record->next_record;

			} while ( current_record != motor_record_list );

			status = SUCCESS;

		} else if ( strcmp( token, "quit" ) == 0 ) {
			fprintf( output, "dbtest complete.\n" );
			exit(0);
		} else {
			status = motor_show_record( MXR_ALL, MXC_ALL, MXT_ALL,
					"record", token, TRUE );
		}

		if ( status != SUCCESS ) {
			fprintf( output, "dbtest: '%s' command failed.\n",
					token );
		}
	}
}

