/*
 * Name:   i_mmx000.h
 *
 * Purpose: Header for MX driver for Newport MM3000 and MM4000
 *          motor controllers.
 *
 *-------------------------------------------------------------------------
 *
 * Copyright 1999 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#ifndef __I_MMX000_H__
#define __I_MMX000_H__

#include "mx_rec.h"
#include "mx_gener.h"

#include "mx_motor.h"
#include "mx_rs232.h"

/* Define the data structures used by a Newport MM3000 or MM4000 interface. */

#define MX_NUM_NEWPORT_MMX000_MOTORS	4

typedef struct {
	MX_RECORD *record;

	MX_INTERFACE controller_interface;
	MX_RECORD *motor_record[MX_NUM_NEWPORT_MMX000_MOTORS];
} MX_MMX000;

#define MXI_MMX000_STANDARD_FIELDS \
  {-1, -1, "controller_interface", MXFT_INTERFACE, NULL, 0, {0}, \
	MXF_REC_TYPE_STRUCT, offsetof(MX_MMX000, controller_interface), \
	{0}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY)}

#ifndef MX_CR
#define MX_CR	'\015'
#define MX_LF	'\012'
#endif

MX_API mx_status_type mxi_mmx000_initialize_type( long type );
MX_API mx_status_type mxi_mmx000_create_record_structures( MX_RECORD *record );
MX_API mx_status_type mxi_mmx000_finish_record_initialization(
							MX_RECORD *record );
MX_API mx_status_type mxi_mmx000_delete_record( MX_RECORD *record );
MX_API mx_status_type mxi_mmx000_read_parms_from_hardware( MX_RECORD *record );
MX_API mx_status_type mxi_mmx000_write_parms_to_hardware( MX_RECORD *record );
MX_API mx_status_type mxi_mmx000_open( MX_RECORD *record );
MX_API mx_status_type mxi_mmx000_close( MX_RECORD *record );
MX_API mx_status_type mxi_mmx000_resynchronize( MX_RECORD *record );

MX_API mx_status_type mxi_mmx000_getchar( MX_GENERIC *generic,
					char *c, int flags );
MX_API mx_status_type mxi_mmx000_putchar( MX_GENERIC *generic,
					char c, int flags );
MX_API mx_status_type mxi_mmx000_read( MX_GENERIC *generic,
					void *buffer, size_t count );
MX_API mx_status_type mxi_mmx000_write( MX_GENERIC *generic,
					void *buffer, size_t count );
MX_API mx_status_type mxi_mmx000_input_is_available( MX_GENERIC *generic,
						int *input_available );
MX_API mx_status_type mxi_mmx000_discard_unread_input( MX_GENERIC *generic,
							int debug_flag );
MX_API mx_status_type mxi_mmx000_discard_unwritten_output( MX_GENERIC *generic,
							int debug_flag );

extern MX_RECORD_FUNCTION_LIST mxi_mmx000_record_function_list;
extern MX_GENERIC_FUNCTION_LIST mxi_mmx000_generic_function_list;

extern long mxi_mmx000_num_record_fields;
extern MX_RECORD_FIELD_DEFAULTS *mxi_mmx000_rfield_def_ptr;

/* === Driver specific functions === */

MX_API mx_status_type mxi_mmx000_turn_motor_drivers_on(
			MX_MMX000 *mmx000, int debug_flag );

MX_API mx_status_type mxi_mmx000_command( MX_MMX000 *mmx000, char *command,
	char *response, int response_buffer_length, int debug_flag );

MX_API mx_status_type mxi_mmx000_getline( MX_MMX000 *mmx000,
			char *buffer, long buffer_size, int debug_flag );

MX_API mx_status_type mxi_mmx000_putline( MX_MMX000 *mmx000,
			char *buffer, int debug_flag );

#endif /* __I_MMX000_H__ */
