/*
 * Name:    i_vme58.h
 *
 * Purpose: Header for MX driver for Oregon Microsystems VME58 motor
 *          controllers.  This driver uses the ESRF Linux device driver
 *          for m68k Linux running on a Motorola 680x0 VME system
 *          controller.
 *
 * Author:  William Lavender
 *
 *--------------------------------------------------------------------------
 *
 * Copyright 2000 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#ifndef __I_VME58_H__
#define __I_VME58_H__

#include "mx_rec.h"
#include "mx_gener.h"

#include "mx_motor.h"
#include "mx_rs232.h"

/* Define the data structures used by a VME58 controller. */

#define MX_MAX_VME58_AXES	8

#define MXT_VME58_UNKNOWN	0
#define MXT_VME58_8		1
#define MXT_VME58_4E		2

#define MX_VME58_AXIS_NAMES	"XYZTUVRS"

typedef struct {
	MX_RECORD *record;

	char device_name[MXU_FILENAME_LENGTH + 1];
	int device_fd;		/* Unix file descriptor */

	int controller_type;
	int num_axes;

	MX_RECORD *motor_array[MX_MAX_VME58_AXES];
} MX_VME58;

#define MXI_VME58_STANDARD_FIELDS \
  {-1, -1, "device_name", MXFT_STRING, NULL, 1, {MXU_FILENAME_LENGTH}, \
	MXF_REC_TYPE_STRUCT, offsetof(MX_VME58, device_name), \
	{sizeof(char)}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY)}, \
  \
  {-1, -1, "controller_type", MXFT_INT, NULL, 0, {0}, \
	MXF_REC_TYPE_STRUCT, offsetof(MX_VME58, controller_type), \
	{0}, NULL, 0}, \
  \
  {-1, -1, "num_axes", MXFT_INT, NULL, 0, {0}, \
	MXF_REC_TYPE_STRUCT, offsetof(MX_VME58, num_axes), \
	{0}, NULL, 0}

#ifndef MX_CR
#define MX_CR	'\015'
#define MX_LF	'\012'
#endif

MX_API mx_status_type mxi_vme58_initialize_type( long type );
MX_API mx_status_type mxi_vme58_create_record_structures(
							MX_RECORD *record );
MX_API mx_status_type mxi_vme58_finish_record_initialization(
							MX_RECORD *record );
MX_API mx_status_type mxi_vme58_delete_record( MX_RECORD *record );
MX_API mx_status_type mxi_vme58_read_parms_from_hardware(
					MX_RECORD *record );
MX_API mx_status_type mxi_vme58_write_parms_to_hardware(
					MX_RECORD *record );
MX_API mx_status_type mxi_vme58_open( MX_RECORD *record );
MX_API mx_status_type mxi_vme58_close( MX_RECORD *record );
MX_API mx_status_type mxi_vme58_resynchronize( MX_RECORD *record );

MX_API mx_status_type mxi_vme58_getchar( MX_GENERIC *generic,
					char *c, int flags );
MX_API mx_status_type mxi_vme58_putchar( MX_GENERIC *generic,
					char c, int flags );
MX_API mx_status_type mxi_vme58_read( MX_GENERIC *generic,
					void *buffer, size_t count );
MX_API mx_status_type mxi_vme58_write( MX_GENERIC *generic,
					void *buffer, size_t count );
MX_API mx_status_type mxi_vme58_input_is_available( MX_GENERIC *generic,
						int *input_available );
MX_API mx_status_type mxi_vme58_discard_unread_input(
				MX_GENERIC *generic, int debug_flag );
MX_API mx_status_type mxi_vme58_discard_unwritten_output(
				MX_GENERIC *generic, int debug_flag );

extern MX_RECORD_FUNCTION_LIST mxi_vme58_record_function_list;
extern MX_GENERIC_FUNCTION_LIST mxi_vme58_generic_function_list;

extern long mxi_vme58_num_record_fields;
extern MX_RECORD_FIELD_DEFAULTS *mxi_vme58_rfield_def_ptr;

/* === Driver specific functions === */

MX_API mx_status_type mxi_vme58_command(
	MX_VME58 *vme58,
	char *command, char *response, int response_buffer_length,
	int debug_flag );

#endif /* __I_VME58_H__ */
