/*
 * Copyright 1999 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

/*
 * Name:    mx_din.c
 *
 * Purpose: MX function library for digital input devices.
 */

#include <stdio.h>
#include <stdlib.h>

#include "mxconfig.h"
#include "mx_util.h"
#include "mx_rec.h"
#include "mx_drivr.h"
#include "mx_din.h"

MX_EXPORT mx_status_type
mx_digital_input_read( MX_RECORD *record, unsigned long *value )
{
	const char fname[] = "mx_digital_input_read()";

	MX_DIGITAL_INPUT *digital_input;
	MX_DIGITAL_INPUT_FUNCTION_LIST *function_list;
	mx_status_type ( *read_fn ) ( MX_DIGITAL_INPUT * );
	mx_status_type status;

	if ( record == (MX_RECORD *) NULL ) {
		return mx_error( MXE_NULL_ARGUMENT, fname,
			"MX_RECORD pointer passed is NULL.");
	}

	digital_input = (MX_DIGITAL_INPUT *) record->record_class_struct;

	if ( digital_input == (MX_DIGITAL_INPUT *) NULL ) {
		return mx_error( MXE_NULL_ARGUMENT, fname,
			"MX_DIGITAL_INPUT pointer for record '%s' is NULL.",
			record->name );
	}

	function_list = (MX_DIGITAL_INPUT_FUNCTION_LIST *)
				(record->class_specific_function_list);

	if ( function_list == (MX_DIGITAL_INPUT_FUNCTION_LIST *) NULL ) {
		return mx_error( MXE_CORRUPT_DATA_STRUCTURE, fname,
		"MX_DIGITAL_INPUT_FUNCTION_LIST ptr for record '%s' is NULL.",
			record->name );
	}

	read_fn = function_list->read;

	if ( read_fn == NULL ) {
		return mx_error( MXE_CORRUPT_DATA_STRUCTURE, fname,
			"read function ptr for record '%s' is NULL.",
			record->name );
	}

	/* All is well, so invoke the function. */

	status = (*read_fn)( digital_input );

	*value = digital_input->value;

	return status;
}

