/*
 * mstop.c  --  Device stop function.
 *
 *-----------------------------------------------------------------------
 *
 * Copyright 1999-2000 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#include <stdio.h>
#include <string.h>

#include "motor.h"

int
motor_stop_fn( int argc, char *argv[] )
{
	MX_RECORD *record;
	long long_value;
	double double_value;
	mx_status_type mx_status;

	if ( argc != 3 ) {
		fprintf(output,
"Usage:  stop 'devicename' - stops moving or counting for 'devicename'\n"
		);
		return FAILURE;
	}

	record = mx_get_record( motor_record_list, argv[2] );

	if ( record == (MX_RECORD *) NULL ) {
		fprintf(output,
		"stop is only supported for motors, scalers, and timers\n" );

		return FAILURE;
	}

	/* Find out what kind of device this is. */

	if ( record->mx_superclass == MXR_INTERFACE ) {
		fprintf(output,"stop is only supported for device records.\n");
		return FAILURE;
	}

	switch( record->mx_class ) {
	case MXC_MOTOR:
		mx_status = mx_motor_soft_abort( record );
		break;
	case MXC_SCALER:
		mx_status = mx_scaler_stop( record, &long_value );
		break;
	case MXC_TIMER:
		mx_status = mx_timer_stop( record, &double_value );
		break;
	default:
		fprintf(output,
		"stop is only supported for motors, scalers, and timers\n" );

		return FAILURE;
		break;
	}

	if ( mx_status.code == MXE_SUCCESS ) {
		return SUCCESS;
	} else {
		return FAILURE;
	}
}

